import { useState, useEffect, useRef, memo } from "react";
import type { BaseSyntheticEvent } from "react";
import { useStepContext } from "@/app/(clean)/signup/Context";
import { IMaskInput } from 'react-imask';
import { toast } from 'react-toastify';

export default memo(function Step0(){
	const [step, setStep] = useStepContext();
	const [internal_step, setInternalStep] = useState<'phone'|'otp'>('phone');
	const ref_phone = useRef<any>(null);
	const ref_otp = useRef<HTMLInputElement>(null);
	const [phone, setPhone] = useState('');
	const [phone_status, setPhoneStatus] = useState<'info'|'success'|'error'>('info');
	const [otp, setOtp] = useState('');
	const [otp_error, setOtpError] = useState(false);

	function verify(){
		if(phone.length===10){
			toast.info('A code has been sent.');
			setPhoneStatus('success');
			setInternalStep('otp');
		}
		else {
			setPhoneStatus('error');
			ref_phone.current!.element.focus();
		}
	}

	function resendOtp(){
		toast.info('A code has been sent.');
		setOtp('');
		ref_otp.current!.focus();
	}

	useEffect(()=>{
		if(otp.length===4){
			if(otp==='0000') setOtpError(true);
			else{
				toast.success('OTP has been verified.');
				setStep(1);
			}
		} else setOtpError(false);
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, [otp]);

	return (
		<div className="fixed left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2 w-[20.3125rem]">
			<h1 className="text-brand-black text-center text-[3.5rem] leading-[3.5rem] font-bold">Hello there!</h1>
			<p className="text-brand-black/50 text-center leading-[1.0625rem] mt-2.5">Enter your phone number below to Sign up.</p>
			<div>
				<div className="grid grid-cols-[1fr_auto] gap-x-2 justify-around items-center border border-base-content/20 rounded-[0.3125rem] mt-[1.6875rem]">
					<label className="input-float">
						<IMaskInput
							type='tel'
							ref={ref_phone}
							mask={[
								{mask: ''},
								{mask: '000'},
								{mask: '(000) 000'},
								{mask: '(000) 000-0000'},
							]}
							unmask={true}
							onAccept={(phone)=>{setPhone(phone); setPhoneStatus('info'); setInternalStep('phone');}}
							placeholder=""
							className="!border-none"
						/>
						<p>Phone number</p>
					</label>
					<div className="w-6 h-6 me-4">
						{ phone_status==='info' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaInfo.svg" alt="icon" loading='lazy' data-tooltip-id="tooltip" data-tooltip-class-name="!bg-info" data-tooltip-content='Phone number is required' /> }
						{ phone_status==='success' && <img src="https://ik.imagekit.io/choreless/v2/icons/FigmaSuccess.svg" alt="icon" loading='lazy' /> }
						{ phone_status==='error' && <img src="https://ik.imagekit.io/choreless/v2/icons/MaterialSymbolsCancelRounded.svg" alt="icon" loading='lazy' /> }
					</div>
				</div>
				{ phone_status==='error' && <p className="text-error">* Invalid phone number</p> }
			</div>
			{
				internal_step==='phone' ? <button onClick={verify} className="btn w-full h-[3.75rem] rounded-[0.3125rem] text-2xl mt-[1.6875rem] px-5 py-[0.9375rem] text-white bg-brand-orange border-brand-orange hover:text-brand-orange hover:bg-transparent hover:border-brand-orange">Verify</button>
				:
				<div>
					<div className="px-0 grid grid-cols-[1fr_auto] justify-around items-center mt-[1.6875rem]">
						<label className="input-float w-full h-full">
							<input type="text" ref={ref_otp} value={otp} onInput={(event:BaseSyntheticEvent<InputEvent>)=>{setOtp(event.target.value)}} maxLength={4} placeholder="" className="!border-r-0 !rounded-r-none" />
							<p>Code</p>
						</label>
						<div className="input border-base-content/20 rounded-[0.3125rem] !outline-none h-[3.75rem] rounded-s-none border-s-0 flex items-center">
							<button onClick={resendOtp} className="btn btn-sm bg-transparent border-none shadow-none hover:bg-brand-orange hover:text-white uppercase">RESEND!</button>
						</div>
					</div>
					{ otp_error && <p className="text-error">* Invalid OTP</p> }
				</div>
			}
			<p className="text-brand-black/50 text-xs text-center mt-[1.6875rem]">Your order status will be updated via this phone number.</p>
		</div>
	)
})
